#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - installation file for motion services on EIS/FAIR
#
# Copyright (c) 2001-2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2007-08-31  jed
# Last Update:  $Id: install.sh 30049 2012-02-29 20:01:52Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib
. /var/install/include/check-eisfair-version

#exec 2>/tmp/motion-install-trace-$$.log
#set -x

module_name="motion"
installfile=/var/run/${module_name}.install

mecho -info "running install.sh ..."

# update shared library file
update_jedlib ${module_name}

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        motionconfig_path=/var/motion
        motion_apache_user="wwwrun"
        motion_apache_group="nogroup"

        ### symbolic links
        mecho "creating symbolic links ..."

        rm -f /etc/rc2.d/[KS]??${module_name}

        ln -sf /etc/init.d/${module_name} /etc/rc2.d/K33${module_name}
        ln -sf /etc/init.d/${module_name} /etc/rc2.d/S67${module_name}

        # update vloopback kernel module
        kernel_version=`uname -r`

        if [ ! -d /lib/modules/${kernel_version}/misc ]
        then
            # create directory
            mkdir -p /lib/modules/${kernel_version}/misc
        fi

        case ${kernel_version} in
            2.4.* )
                # if [ -f /tmp/vloopback-0.91.o ]
                # then
                #     mv -f /tmp/vloopback-0.91.so     /lib/modules/${kernel_version}/misc/vloopback.so
                # fi

                if [ -f /tmp/vloopback-0.92snap1.o ]
                then
                    mv -f /tmp/vloopback-0.92snap1.o /lib/modules/${kernel_version}/misc/vloopback.so
                fi
                ;;

            2.6.* )
                # if [ -f /tmp/vloopback-1.0.o ]
                # then
                #     mv -f /tmp/vloopback-1.0.o /lib/modules/${kernel_version}/misc/vloopback.so
                # fi
                ;;
        esac
        ;;
    *)
        # default to eisfair-2
        motionconfig_path=/data/packages/motion
        motion_apache_user="www-data"
        motion_apache_group="www-data"

        ### symbolic links
        mecho "creating symbolic links ..."

        rm -f /etc/rc[0126S].d/[KS]??${module_name}

        ln -sf /etc/init.d/${module_name} /etc/rc0.d/K33${module_name}
        ln -sf /etc/init.d/${module_name} /etc/rc1.d/K33${module_name}
        ln -sf /etc/init.d/${module_name} /etc/rc6.d/K33${module_name}
        ln -sf /etc/init.d/${module_name} /etc/rcS.d/K33${module_name}
        ln -sf /etc/init.d/${module_name} /etc/rc2.d/S67${module_name}
        ;;
esac

# menue entry does not exist - create it
mecho "adding ${module_name} module menu  ..."

# menu
mecho "adding menu ..."
/var/install/bin/add-menu -menu "setup.services.menu" "setup.services.${module_name}.menu" "Motion Service"

# spool directory
mecho "creating config directory ..."
for DIR in events log
do
    mkdir -p ${motionconfig_path}/${DIR}

    chown root: ${motionconfig_path}/${DIR}
done

chown root: ${motionconfig_path}

for FNAME in cambozola.jar motionbrowser.tgz motionbrowser.tgz.lst motion-cgi.tgz motion-cgi.tgz.lst \
             motion_collect_jpg.sh motion_purge_jpg.sh motion_change_owner.sh motion_db_backup_restore.sh \
             motion_send_file.sh motion_pixel_changes.sh motion_update_db_fields.sh motionmail.pl \
             motionmail.conf.EXAMPLE
do
    if [ -f /tmp/${FNAME} ]
    then
        mv /tmp/${FNAME} ${motionconfig_path}/
    fi
done

chown root: ${motionconfig_path}/*

# change access rights
chmod 6755                   /usr/local/bin/motion
chown ${motion_apache_user}  /usr/local/bin/motion
chgrp ${motion_apache_group} /usr/local/bin/motion

# check if script exists
if [ ! -f /usr/local/bin/send_file_from_cmd.sh ]
then
    mv /tmp/send_file_from_cmd.sh /usr/local/bin/
else
    rm -f send_file_from_cmd.sh
fi

# video devices
mecho "checking/creating devices..."
for VDEV in 0 1
do
    if [ ! -c /dev/video${VDEV} ]
    then
        mecho "- creating /dev/video${VDEV} ..."
        mknod -m 0666 /dev/video${VDEV} c 81 ${VDEV}
    fi
done

ln -sf /dev/video0 /dev/video

# remove obsolete debug files
rm -f /var/install/config.d/motion-trace-*.log

# move old files to backup directory and create backup
/var/install/bin/backup-file -quiet ${module_name}

# install/update package configuration file
update=false
if install_config ${module_name}
then
    update=true
fi

# configuration
mecho "creating ${module_name} configuration ..."

if [ "${update}" = "true" ]
then
    # updated installation
    /var/install/config.d/${module_name}.sh
    if [ -f /etc/init.d/${module_name} ]
    then
        /etc/init.d/${module_name} restart
    fi
else
    # new installation
    /var/install/bin/edit -apply "${module_name}" "Edit ${module_name} services configuration"
fi

exit 0
