#!/bin/sh -vx
#----------------------------------------------------------------------------------------
# /[data/packages|var]/motion/motion_pixel_changes.sh - find jpg files, read pixel changes
#     and create a csv file containing that data.
#
# Copyright (c) 2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2011-10-24  jed
# Last Update:  $Id: motion_pixel_changes.sh 29043 2011-10-27 18:50:48Z jed $
#
# Usage:        motion_pixel_changes.sh start-path [output-file]
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/jedlib

# start path, e.g. /var/www/htdocs/motion/camera-3
start_path=$1

# output file, e.g. /tmp/motion-out.csv
if [ "$2" != "" ]
then
    csv_file=$2
else
    csv_file=/tmp/motion-out.csv
fi

if [ "${start_path}" != "" ]
then
    {
        echo "Datum,Zeit,Rahmen,Pixelaenderung"

        find ${start_path} -iname '??-??-*.jpg' | while read line
        do
            # /var/www/htdocs/motion/camera-3/2011/10/19/09/48/45-03-15089.jpg
            # 19-03-0.jpg
            file_name=`basename "${line}"`

            # 2011/10/23/23/05
            date_str=`dirname "${line}" | sed -e "s#^${start_path}/##"`

            year=`echo ${date_str} | cut -d/ -f1`
            month=`echo ${date_str} | cut -d/ -f2`
            day=`echo ${date_str} | cut -d/ -f3`
            hour=`echo ${date_str} | cut -d/ -f4`
            minute=`echo ${date_str} | cut -d/ -f5`
            second=`echo ${file_name} | cut -d- -f1`
            frame=`echo ${file_name} | cut -d- -f2`
            pixel=`echo ${file_name} | cut -d- -f3 | sed 's#.jpg$##'`

          # echo "date:${day}.${month}.${year}"
          # echo "time:${hour}:${minute}:${second}"
          # echo "frame:${frame}"
          # echo "pixel:${pixel}"

            echo "${day}.${month}.${year},${hour}:${minute}:${second},${frame},${pixel}"
        done
    } > /tmp/motion-out.csv

    echo "pixel changes have been written to csv file '${csv_file}'."
else
    echo "no start path given!"
    echo
    echo "Usage: $0 start-path [output-file]"
    echo
fi
