#!/bin/sh
#----------------------------------------------------------------------------------------
# /[data/packages|var]/motion/motion_purge_jpg.sh - purge old jpg-files
#
# Copyright (c) 2008-2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2008-08-27  jed
# Last Update:  $Id: motion_purge_jpg.sh 29043 2011-10-27 18:50:48Z jed $
#
# Usage:        motion_purge_jpg.sh thread-number [keep-days]
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/check-eisfair-version

#exec 2>/tmp/motion-purge-$$.log
#set -x

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        def_doc_root=/var/www/htdocs
        ;;
    *)
        # default eisfair-2
        def_doc_root=/data/www/htdocs
        ;;
esac

thread=${1}
keepdays=${2}

if [ "${keepdays}" = "" ]
then
    keepdays=1
fi

apache2file=/etc/config.d/apache2
motionfile=/etc/config.d/motion

MOTION_SQL_HOST='localhost'
MOTION_SQL_DATABASE='motiondb'
MOTION_SQL_TABLE='security'

if [ $# -ge 1 ]
then
    if [ "${thread}" != "" ]
    then
        ### load motion configuration ###
        if [ -f ${motionfile} ]
        then
            webtmp=/tmp/motionroot.$$

            grep "^MOTION_SQL_" ${motionfile} > ${webtmp}
            . ${webtmp}
            rm -f ${webtmp}
        fi

        ### load apache2 configuration ###
        if [ -f ${apache2file} ]
        then
            webtmp=/tmp/motionroot.$$

            grep "^APACHE2_DOCUMENT_ROOT" ${apache2file} > ${webtmp}
            . ${webtmp}
            rm -f ${webtmp}
        else
            APACHE2_DOCUMENT_ROOT=${def_doc_root}
        fi

        START_PATH=${APACHE2_DOCUMENT_ROOT}/motion/camera-${thread}

        # delete file older one day
        for FNAME in `find ${START_PATH} -mtime +${keepdays}|grep -v -x "${START_PATH}"|sort -r`
        do
            if [ "${FNAME}" != "" ]
            then
                rm -f ${FNAME} >/dev/null 2>/dev/null

                if [ $? -ne 0 ]
                then
                    rmdir --ignore-fail-on-non-empty ${FNAME} >/dev/null
                fi
            fi
        done

        if [ "${MOTION_SQL_ENABLED}" = "yes" ]
        then
            date_str="`date -d "${keepdays} day ago" +"%Y-%m-%d %X"`"
            /usr/local/mysql/bin/mysql -h${MOTION_SQL_HOST} -u${MOTION_SQL_USER} -p${MOTION_SQL_PASS} -D${MOTION_SQL_DATABASE} -e "DELETE FROM security WHERE time_stamp < '${date_str}'" 2> /dev/null
        fi
    else
        echo "Error: No thread number given!"
    fi
else
    # help
    echo "Usage: $0 thread-number [keep-days]"
fi
