#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for motion services on EIS/FAIR
#
# Copyright (c) 2001-2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2007-08-31 jed
# Last Update:  $Id: preinstall.sh 29111 2011-11-14 14:30:44Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# read eislib etc.
. /var/install/include/check-eisfair-version

pgmname=`basename $0`

#exec 2>/tmp/motion-preinstall-trace-$$.log
#set -x

# file names
module_name="motion"
apache2file=/etc/config.d/apache2
usbcamfile=/etc/config.d/usbcam
configfile=/etc/config.d/${module_name}
installfile=/var/run/${module_name}.install
deinstallfile=/var/install/deinstall/${module_name}

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        def_doc_root=/var/www/htdocs
        ;;
    *)
        # default eisfair-2
        def_doc_root=/data/www/htdocs
        ;;
esac

colecho "running preinstall.sh ..." gn

# check base version
installed_version=`/var/install/bin/check-version base 1.7.5`

case ${installed_version} in
    not-installed|new ) # wrong version
        colecho "required base package v1.7.5 or newer not installed - installation aborted." br x br
        /var/install/bin/anykey
        exit 1
        ;;
    * ) # installed / old
        ;;
esac

# read eislib
. /var/install/include/eislib

if [ -f ${configfile} ]
then
    # backup existing file
    mecho "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}

    ### load apache2 configuration ###
    if [ -f ${apache2file} ]
    then
        webtmp=/tmp/motionroot.$$

        grep "^APACHE2_DOCUMENT_ROOT" ${apache2file} > ${webtmp}
        . ${webtmp}
        rm -f ${webtmp}
    else
        APACHE2_DOCUMENT_ROOT=${def_doc_root}
    fi

    if [ -d ${APACHE2_DOCUMENT_ROOT}/motion ]
    then
        # create new cgi path directory
        if [ ! -d ${APACHE2_DOCUMENT_ROOT}/motion-cgi ]
        then
            mkdir ${APACHE2_DOCUMENT_ROOT}/motion-cgi
        fi

        # saparate cgi files from camera path
        for FDNAME in control filehandle images COPYING cambozola.jar blank.html index.html \
                      motion-tree.cgi motion.cgi motion.cgi.conf webcam-live-java.cgi \
                      webcam-live.cgi motion.ver
        do
            if [ -f ${APACHE2_DOCUMENT_ROOT}/motion/${FDNAME} -o -d ${APACHE2_DOCUMENT_ROOT}/motion/${FDNAME} ]
            then
                mv ${APACHE2_DOCUMENT_ROOT}/motion/${FDNAME} ${APACHE2_DOCUMENT_ROOT}/motion-cgi/
            fi
        done
    fi

    # process web directories
    for DNAME in ${APACHE2_DOCUMENT_ROOT}/motionbrowser ${APACHE2_DOCUMENT_ROOT}/motion-cgi
    do
        if [ -d ${DNAME} -a ! -f ${DNAME}/motion.ver ]
        then
            # set version dummy marker file
            touch ${DNAME}/motion.ver
        fi
    done
fi

# check for usbcam package
if [ -f ${usbcamfile} ]
then
    grep -q "^START_USBCAM=.yes." ${usbcamfile}

    if [ $? -eq 0 ]
    then
        # usbcam package is still active
        mecho -warn "An active usbcam package has been found. Make sure that"
        mecho -warn "you disable it before you start using the motion package."
        mecho
        mecho -warn "stopping usbcam package ..."

        /etc/init.d/usbcam stop
    fi
fi

# deinstall old software
mecho "deinstalling previously installed software ..."
/var/install/bin/del-package -p ${module_name} update

exit 0
