#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/bin/motion-update - update or generate new motion configuration
#
# Copyright (c) 2001-2012 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2007-09-02  jed
# Last Update:  $Id: motion-update.sh 31918 2012-10-20 16:02:02Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# read eislib
. /var/install/include/eislib
. /var/install/include/configlib
. /var/install/include/jedlib
. /var/install/include/check-eisfair-version

#exec 2>/var/install/config.d/motion-trace-$$.log
#set -x

#------------------------------------------------------------------------------
# function: variable is set
#
# input:  $1 - variable name
# return:  0 - variable set
#          1 - variable not set
#------------------------------------------------------------------------------
variable_set ()
{
    eval _var1=\$"${1}"
    eval _var2=\$"{${1}+EMPTY}"

    if [ -z "${_var1}" ]
    then
        if [ "${_var2}" = "EMPTY" ]
        then
            # variable is empty, but set
            ret=0
        else
            # variable is not set
            ret=1
        fi
    else
        # variable has a value
        ret=0
    fi

    return ${ret}
}

#------------------------------------------------------------------------------
# function: variable is empty
#
# input:  $1 - variable name
# return:  0 - variable empty
#          1 - variable not empty
#------------------------------------------------------------------------------
variable_empty ()
{
    eval _var1=\$"${1}"
    eval _var2=\$"{${1}+EMPTY}"

    if [ -z ${_var1} ]
    then
        if [ "${_var2}" = "EMPTY" ]
        then
            # variable is empty, but set
            ret=0
        else
            # variable is not set
            ret=1
        fi
    else
        # variable has a value
        ret=1
    fi

    return ${ret}
}

#------------------------------------------------------------------------------
# print variable only if it has been set
# $1 - variable name
# $2 - comment
#------------------------------------------------------------------------------
printsetvar ()
{
    if variable_set "${1}"
    then
        printvar "${1}" "${2}"
    fi
}

#------------------------------------------------------------------------------
# import usbcam parameters
#------------------------------------------------------------------------------
read_usbcam ()
{
    mecho "importing usbcam parameters ..."

    # load apache2 configuration
    if [ -f ${apache2file} ]
    then
        webtmp=/tmp/motionroot.$$

        grep "^APACHE2_DOCUMENT_ROOT" ${apache2file} > ${webtmp}
        . ${webtmp}
        rm -f ${webtmp}
    else
        APACHE2_DOCUMENT_ROOT=${def_doc_root}
    fi
                
    # ------------------------------------------------
    # base settings
    # ------------------------------------------------
    START_MOTION="${START_USBCAM}"

    MOTION_N='1'
    MOTION_1_ACTIVE='yes'
    MOTION_1_TEXT_LEFT="${USBCAM_TEXTLEFT}"           # text_left
    MOTION_1_TEXT_RIGHT="${USBCAM_TEXTRIGHT}"         # text_right
    
    if [ "${USBCAM_TEXT_DOUBLE}" = "on" ]
    then
        MOTION_1_TEXT_SIZE="double"                   # text_double
    else
        MOTION_1_TEXT_SIZE="normal"
    fi

    MOTION_1_VIDEO_DEVICE="${USBCAM_DEVICE}"          # videodevice
    MOTION_1_VIDEO_INPUT='8'                          # input

    if [ "${USBCAM_VIDEO_MODUL}" != "" ]
    then
        # first module
        MOTION_MODULES_N='1'
        MOTION_MODULES_1_ACTIVE='yes'
        MOTION_MODULES_1_NAME="${USBCAM_VIDEO_MODUL}"
        MOTION_MODULES_1_OPTIONS=''
    fi

    # -------------------------------------------------
    # video server settings
    # -------------------------------------------------
    MOTION_N='1'
    MOTION_1_ACTIVE='yes'

    MOTION_1_VIDEO_BRIGHTNESS=''
    if [ "${USBCAM_AUTOBRIGHTNESS}" = "on" ]                 # auto_brightness/brightness
    then
        MOTION_1_VIDEO_BRIGHTNESS='auto:'
    fi

    MOTION_1_VIDEO_BRIGHTNESS="${MOTION_1_VIDEO_BRIGHTNESS}${USBCAM_BRIGHTNESS}" 

    MOTION_1_VIDEO_CONTRAST="${USBCAM_CONTRAST}"             # contrast

    # hue=0 - USBCAM_HUE='100'                               # only relevant for NTSC cameras

    MOTION_1_VIDEO_SATURATION="${USBCAM_SATURATION}"         # saturation

    MOTION_1_MOTION_NOISE_TUNE='no'

    MOTION_1_CAPTURE_QUALITY="${USBCAM_WEBCAM_QUALITY}"      # quality
    MOTION_1_VIDEO_ROTATE="${USBCAM_ROTATE}"                 # rotate
    MOTION_1_WEBCAM_PORT="${USBCAM_WEBCAM_PORT}"             # webcam_port

    # -------------------------------------------------
    # camera modul settings
    # -------------------------------------------------
    if [ "${USBCAM_CAM_MODUL}" != "" ]
    then
        if [ "${USBCAM_VIDEO_MODUL}" != "" ]
        then
            # one module already exists, add additional one ...
            MOTION_MODULES_N=`expr ${MOTION_MODULES_N} + 1`
        else
            # first module
            MOTION_MODULES_N='1'
        fi

        eval MOTION_MODULES_${MOTION_MODULES_N}_ACTIVE='yes'
        eval MOTION_MODULES_${MOTION_MODULES_N}_NAME="${USBCAM_CAM_MODUL}"
        eval MOTION_MODULES_${MOTION_MODULES_N}_OPTIONS="${USBCAM_MODUL_CONFIG}"
    fi

    if [ "${USBCAM_DECOMP_MODUL}" != "" ]
    then
        if [ "${USBCAM_VIDEO_MODUL}" != "" -o "${USBCAM_CAM_MODUL}" != "" ]
        then
            # one or more module(s) already exist(s), add additional one ...
            MOTION_MODULES_N=`expr ${MOTION_MODULES_N} + 1`
        else
            # first module
            MOTION_MODULES_N='1'
        fi

        eval MOTION_MODULES_${MOTION_MODULES_N}_ACTIVE='yes'
        eval MOTION_MODULES_${MOTION_MODULES_N}_NAME="${USBCAM_DECOMP_MODUL}"
        eval MOTION_MODULES_${MOTION_MODULES_N}_OPTIONS=''
    fi

    # -------------------------------------------------
    # kernel modul configuration
    # details for this you can find in the documentation
    # -------------------------------------------------
    MOTION_COMMAND_POSTSTART="${USBCAM_AUX_COMMAND}"

    # -------------------------------------------------
    # output configuration
    # -------------------------------------------------
    MOTION_1_CAPTURE_SNAPSHOT="${USBCAM_REPEAT}"             # snapshot_interval

    # target_dir=${APACHE2_DOCUMENT_ROOT}/motion - USBCAM_OUTPUT='/var/www/htdocs/webcam' # target_dir
    mecho "- value of USBCAM_OUTPUT has been replaced by default of '${APACHE2_DOCUMENT_ROOT}/motion'."

    # USBCAM_OFFLINE='offline.jpg'                           # ???
    mecho "- value of USBCAM_OFFLINE has been depricated."

    MOTION_1_VIDEO_WIDTH="${USBCAM_SIZE_X}"                  # width
    MOTION_1_VIDEO_HEIGHT="${USBCAM_SIZE_Y}"                 # height

    # -------------------------------------------------
    # picture collector configuration
    # -------------------------------------------------
    if [ "${USBCAM_PICTURE_COLLECT}" = "yes" ]
    then
        MOTION_1_ON_PICTURESAVE="motion_collect_jpg.sh %t ${USBCAM_COLLECTOR_FOLDER} ${USBCAM_COLLECTOR_COUNT}"

        mecho "- value of USBCAM_COLLECTOR_COUNT has been moved to MOTION_1_ON_PICTURESAVE parameter."
        mecho "- value of USBCAM_COLLECTOR_FOLDER has been moved to MOTION_1_ON_PICTURESAVE parameter."
    fi
}

#------------------------------------------------------------------------------
# rename variables
#------------------------------------------------------------------------------
rename_variables ()
{
    renamed=0
    mecho "renaming parameter(s) ..."
    
  # # v1.0.1
  # if [ ! -z "`grep "^RAZOR_REPORT_MAILBOX_FILE=" $source_conf`" ]
  # then
  #     mecho "- RAZOR_REPORT_MAILBOX_FILE -> RAZOR_REPORT_MAILBOX_FILE_1_NAME"
  #     RAZOR_REPORT_MAILBOX_FILE_1_NAME="${RAZOR_REPORT_MAILBOX_FILE}"
  #     renamed=1
  # fi    
    
    if [ ${renamed} -eq 1 ]
    then
        mecho -info "... read documentation for renamed parameter(s)!"
        anykey
    fi    
}

#------------------------------------------------------------------------------
# modify variables
#------------------------------------------------------------------------------
modify_variables ()
{
    modified=0
    mecho "modifying parameter(s) ..."
    
    # v0.90.0
    if [ "${MOTION_CONTROL_PASS}" = "" ]
    then
        # create random password
        pass_len=8
        randpass="`rand_string ${pass_len}`"

        mecho "- MOTION_CONTROL_PASS, '${MOTION_CONTROL_PASS}' -> '${randpass}'"
        MOTION_CONTROL_PASS="${randpass}"
        modified=1
    fi

    if [ "${MOTION_DEF_TEXT_SIZE}" = "" ]
    then
        MOTION_DEF_TEXT_SIZE="normal"
    fi

    if [ "${MOTION_DEF_CAPTURE_IMAGE}" = "" ]
    then
        MOTION_DEF_CAPTURE_IMAGE="yes"
    fi

    if [ "${MOTION_DEF_CAPTURE_MOVIE}" = "" ]
    then
        MOTION_DEF_CAPTURE_IMAGE="no"
    fi

    if [ ${modified} -eq 1 ]
    then
        mecho -info "... read documentation for modified parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# add variables
#------------------------------------------------------------------------------
add_variables ()
{
    added=0
    mecho "adding new parameter(s) ..."

  # # v0.90.8
    if [ -z "`grep ^MOTION_SQL_ENABLED ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_ENABLED='no'"
        MOTION_SQL_ENABLED='no'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_USER ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_USER='sql-user'"
        MOTION_SQL_USER='sql-user'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_PASS ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_PASS='sql-password'"
        MOTION_SQL_PASS='sql-password'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_DEF_LOG_IMAGE ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_DEF_LOG_IMAGE='yes'"
        MOTION_SQL_DEF_LOG_IMAGE='yes'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_DEF_LOG_SNAPSHOT ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_DEF_LOG_SNAPSHOT='yes'"
        MOTION_SQL_DEF_LOG_SNAPSHOT='yes'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_DEF_LOG_MOVIE ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_DEF_LOG_MOVIE='yes'"
        MOTION_SQL_DEF_LOG_MOVIE='yes'
        added=1
    fi

    if [ -z "`grep ^MOTION_SQL_DEF_LOG_TIMELAPS ${source_conf}`" ]
    then
        mecho "- MOTION_SQL_DEF_LOG_TIMELAPS='yes'"
        MOTION_SQL_DEF_LOG_TIMELAPS='yes'
        added=1
    fi

    if [ -z "`grep ^MOTION_CONTROL_WEBGUI ${source_conf}`" ]
    then
        # upgrade -> use motion-cgi as default
        mecho "- MOTION_CONTROL_WEBGUI='motioncgi'"
        MOTION_CONTROL_WEBGUI='motioncgi'
        added=1
    fi

    if [ ${added} -eq 1 ]
    then
        mecho -info "... read documentation for new parameter(s)!"
        anykey
    fi
}

#------------------------------------------------------------------------------
# delete variables
#------------------------------------------------------------------------------
delete_variables ()
{
    deleted=0
    mecho "deleting old parameters ..."

  # for varname in "ANTISPAM_LOG_COUNT ANTISPAM_LOG_INTERVAL ANTISPAM_ACTIVATE_OSIRU_RBL"
  # do
  #     if [ ! -z "`grep \"^$varname\" $source_conf`" ]
  #     then
  #         mecho "- $varname"
  #         deleted=1
  #     fi
  # done

    if [ ${deleted} -eq 1 ]
    then
        anykey
    fi
}

#------------------------------------------------------------------------------
# create new configuration
#------------------------------------------------------------------------------
create_config ()
{
    mecho "updating/creating configuration ..."

    {
        #------------------------------------------------------------------------------
        printgpl -conf "motion" "2007-09-02" "jed"
        #------------------------------------------------------------------------------

        if [ "${MOTION_DO_DEBUG}" = "yes" ]
        then
            # debug active
            printvar "MOTION_DO_DEBUG" "debug mode: yes or no"
        elif [ "${MOTION_DO_DEBUG}" = "no" ]
        then
            # debug inactive
            printvar "MOTION_DO_DEBUG" "debug mode: yes or no"
        else
            # debug parameter exists but not active
            if [ -n "`grep MOTION_DO_DEBUG $source_conf`" ]
            then
                echo "# MOTION_DO_DEBUG='yes'                   # debug mode: yes or no"
            fi
        fi

        #------------------------------------------------------------------------------
        printgroup "general settings"
        #------------------------------------------------------------------------------
        printvar "START_MOTION"                 "enable motion program: yes or no"
        echo
        printvar "MOTION_SETUPMODE_ENABLED"     "enable setup mode: yes or no"
        echo
        printvar "MOTION_COMMAND_PRESTART"      "optional pre-start command"
        printvar "MOTION_COMMAND_POSTSTART"     "optional post-start command"

        #------------------------------------------------------------------------------
        printgroup "video kernel modules"
        #------------------------------------------------------------------------------
        printvar "MOTION_MODULES_N"             "number of kernel modules to load"

        idx=1
        while [ ${idx} -le ${MOTION_MODULES_N} ]
        do
            eval active='$MOTION_MODULES_'${idx}'_ACTIVE'

            # set defaults
            if [ "${active}" = "" ]
            then
                active='no'
            fi

            eval "MOTION_MODULES_${idx}_ACTIVE='${active}'"

            printvar "MOTION_MODULES_${idx}_ACTIVE"      "${idx}. active: yes or no"
            printvar "MOTION_MODULES_${idx}_NAME"        "   name of kernel module"
            printvar "MOTION_MODULES_${idx}_OPTIONS"     "   optional module parameters"

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printgroup "control web interface"
        #------------------------------------------------------------------------------
        printvar "MOTION_CONTROL_PORT"          "tcp-port of web control interface"
        printvar "MOTION_CONTROL_USER"          "username"
        printvar "MOTION_CONTROL_PASS"          "password"
        echo
        printvar "MOTION_CONTROL_WEBGUI"        "install web-gui"

        #------------------------------------------------------------------------------
        printgroup "mysql settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_SQL_ENABLED"           "enable MySQL support: yes or no"
        printvar "MOTION_SQL_USER"              "MySQL user"
        printvar "MOTION_SQL_PASS"              "MySQL password"
        printvar "MOTION_SQL_DEF_LOG_IMAGE"     "log message on jpeg file creation"
        printvar "MOTION_SQL_DEF_LOG_SNAPSHOT"  "log message on snapshot creation"
        printvar "MOTION_SQL_DEF_LOG_MOVIE"     "log message on movie creation"
        printvar "MOTION_SQL_DEF_LOG_TIMELAPS"  "log message on timelaps movie creation"

        #------------------------------------------------------------------------------
        printgroup "default: video settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_DEF_VIDEO_FREQ"        "TV tuner frequency (kHz)"
        printvar "MOTION_DEF_VIDEO_ROTATE"      "rotate image this number of degrees"
        printvar "MOTION_DEF_VIDEO_WIDTH"       "camera dependent image width (pixels)"
        printvar "MOTION_DEF_VIDEO_HEIGHT"      "camera dependent image height (pixels)"
        printvar "MOTION_DEF_VIDEO_FRAMERATE"   "frames to be captured per second"
        printvar "MOTION_DEF_VIDEO_FRAMETIME"   "time between capturing pictures (sec)"
        printvar "MOTION_DEF_VIDEO_BRIGHTNESS"  "brightness of a video device, see doc!"
        printvar "MOTION_DEF_VIDEO_CONTRAST"    "contrast of a video device"
        printvar "MOTION_DEF_VIDEO_SATURATION"  "saturation of a video device"

        #------------------------------------------------------------------------------
        printgroup "default: motion detection settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_DEF_MOTION_TRIGGER"      "number of changed pixels in an image that triggers motion detection"
      # printvar "MOTION_DEF_MOTION_TRIGGER_TUNE" "automatically tune threshold down"
        printvar "MOTION_DEF_MOTION_NOISE_TUNE"   "automatically tune noise threshold"
        printvar "MOTION_DEF_MOTION_NOISE_LEVEL"  "noise threshold for motion detection"
        printvar "MOTION_DEF_MOTION_LIGHTSWITCH"  "ignore sudden massive light intensity changes"
        printvar "MOTION_DEF_MOTION_FRAMES"       "number of frames to detect motion"
        printvar "MOTION_DEF_MOTION_PRECAPTURE"   "number of frames to capture before motion"
        printvar "MOTION_DEF_MOTION_POSTCAPTURE"  "number of frames to capture after motion"
        printvar "MOTION_DEF_MOTION_ENDGAP"       "end of motion gap before event trigger"
        printvar "MOTION_DEF_MOTION_LOCATE"       "locate/draw a box around the moving object"

        #------------------------------------------------------------------------------
        printgroup "default: mask settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_DEF_MASK_FILE"         "PGM file to use as a sensitivity mask"
        printvar "MOTION_DEF_MASK_SPEED"        "dynamically create a mask file"

        #------------------------------------------------------------------------------
        printgroup "default: capture settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_DEF_TEXT_LEFT"         "default text lable, left side"
        printvar "MOTION_DEF_TEXT_RIGHT"        "default text lable, right side"
        printvar "MOTION_DEF_TEXT_SIZE"         "default text size: normal or double"
        echo
        printvar "MOTION_DEF_CAPTURE_IMAGE"     "create jpeg file on event"
        printvar "MOTION_DEF_CAPTURE_ALL"       "always save images even if no motion"
        printvar "MOTION_DEF_CAPTURE_SNAPSHOT"  "create snapshot each n seconds"
        printvar "MOTION_DEF_CAPTURE_QUALITY"   "jpeg image quality"
        printvar "MOTION_DEF_CAPTURE_MOVIE"     "create mpeg movie at start of an event"
        printvar "MOTION_DEF_CAPTURE_LENGTH"    "maximum length of an mpeg movie (sec)"
        printvar "MOTION_DEF_CAPTURE_TIMELAPS"  "create timelaps movie saving a frame each n seconds"
        printvar "MOTION_DEF_CAPTURE_CODEC"     "video codec"
      # echo
      # printvar "MOTION_DEF_TARGET_PATH"       "target directory for pictures/films"
        echo
        printvar "MOTION_DEF_WEBCAM_PORT"       "tcp-port of webcam interface"
        printvar "MOTION_DEF_WEBCAM_MOTION"     "output 1 fps when no motion is detected"
        printvar "MOTION_DEF_WEBCAM_FRAMERATE"  "maximum framerate for webcam streams"

        #------------------------------------------------------------------------------
        printgroup "default: event settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_DEF_ON_CAMERALOST"     "execute command when camera connection can't be opened or if it is lost"
        printvar "MOTION_DEF_ON_EVENTSTART"     "execute command when an event starts"
        printvar "MOTION_DEF_ON_EVENTEND"       "execute command when an event ends"
        printvar "MOTION_DEF_ON_MOTIONDETECT"   "execute command when motion is detected"
        printvar "MOTION_DEF_ON_MOVIESTART"     "execute command when a movie file is created"
        printvar "MOTION_DEF_ON_MOVIEEND"       "execute command when a movie file is closed"
        printvar "MOTION_DEF_ON_PICTURESAVE"    "execute command when a picture is saved"

        #------------------------------------------------------------------------------
        printgroup "device specific: general settings"
        #------------------------------------------------------------------------------
        printvar "MOTION_N"                     "number of video devices"

        if [ ${MOTION_N} -eq 0 ]
        then
            imax=1
        else
            imax=${MOTION_N}
        fi

        idx=1
        while [ ${idx} -le ${imax} ]
        do
            eval active='$MOTION_'${idx}'_ACTIVE'

            # set defaults
            if [ "${active}" = "" ]
            then
                if [ ${idx} -eq 1 ]
                then
                    # automatically activate if first entry
                    active='yes'
                else
                    active='no'
                fi
            fi

            #------------------------------------------------------------------------------
            printgroup "device specific: individual settings"
            #------------------------------------------------------------------------------
            eval "MOTION_${idx}_ACTIVE='${active}'"

            echo
            printvar    "MOTION_${idx}_ACTIVE"      "${idx}. activate configuration: yes or no"
            printsetvar "MOTION_${idx}_TEXT_LEFT"   "   text lable, left side"
            printsetvar "MOTION_${idx}_TEXT_RIGHT"  "   text lable, right side"
            printsetvar "MOTION_${idx}_TEXT_SIZE"   "   text size: normal or double"
            echo
            printvar "MOTION_${idx}_VIDEO_DEVICE"   "   device used for capturing"
            printvar "MOTION_${idx}_VIDEO_INPUT"    "   video input to be used"
            echo
            printvar "MOTION_${idx}_NETCAM_URL"     "   URL to use for network camera"
            printvar "MOTION_${idx}_NETCAM_USER"    "   username for network camera"
            printvar "MOTION_${idx}_NETCAM_PASS"    "   password for network camera"

            for VNAME in FREQ ROTATE WIDTH HEIGHT FRAMERATE FRAMETIME BRIGHTNESS CONTRAST SATURATION
            do
                if variable_set "MOTION_${idx}_VIDEO_${VNAME}"
                then
                    #------------------------------------------------------------------------------
                    printgroup "device specific: video settings"
                    #------------------------------------------------------------------------------
                    break
                fi
            done
                    
            printsetvar "MOTION_${idx}_VIDEO_FREQ"        "   TV tuner frequency (kHz)"
            printsetvar "MOTION_${idx}_VIDEO_ROTATE"      "   rotate image this number of degrees"
            printsetvar "MOTION_${idx}_VIDEO_WIDTH"       "   camera dependent image width (pixels)"
            printsetvar "MOTION_${idx}_VIDEO_HEIGHT"      "   camera dependent image height (pixels)"
            printsetvar "MOTION_${idx}_VIDEO_FRAMERATE"   "   frames to be captured per second"
            printsetvar "MOTION_${idx}_VIDEO_FRAMETIME"   "   time between capturing pictures (sec)"
            printsetvar "MOTION_${idx}_VIDEO_BRIGHTNESS"  "   brightness of a video device, see doc!"
            printsetvar "MOTION_${idx}_VIDEO_CONTRAST"    "   contrast of a video device"
            printsetvar "MOTION_${idx}_VIDEO_SATURATION"  "   saturation of a video device"

          # for VNAME in TRIGGER TRIGGER_TUNE NOISE_TUNE NOISE_LEVEL LIGHTSWITCH \
          #              FRAMES PRECAPTURE POSTCAPTURE ENDGAP LOCATE
            for VNAME in TRIGGER NOISE_TUNE NOISE_LEVEL LIGHTSWITCH FRAMES PRECAPTURE POSTCAPTURE ENDGAP LOCATE
            do
                if variable_set "MOTION_${idx}_MOTION_${VNAME}"
                then
                    #------------------------------------------------------------------------------
                    printgroup "default: motion detection settings"
                    #------------------------------------------------------------------------------
                    break
                fi
            done
                    
            printsetvar "MOTION_${idx}_MOTION_TRIGGER"      "number of changed pixels in an image that triggers motion detection"
          # printsetvar "MOTION_${idx}_MOTION_TRIGGER_TUNE" "automatically tune threshold down"
            printsetvar "MOTION_${idx}_MOTION_NOISE_LEVEL"  "noise threshold for motion detection"
            printsetvar "MOTION_${idx}_MOTION_NOISE_TUNE"   "automatically tune noise threshold"
            printsetvar "MOTION_${idx}_MOTION_LIGHTSWITCH"  "ignore sudden massive light intensity changes"
            printsetvar "MOTION_${idx}_MOTION_FRAMES"       "number of frames to detect motion"
            printsetvar "MOTION_${idx}_MOTION_PRECAPTURE"   "number of frames to capture before motion"
            printsetvar "MOTION_${idx}_MOTION_POSTCAPTURE"  "number of frames to capture after motion"
            printsetvar "MOTION_${idx}_MOTION_ENDGAP"       "end of motion gap before event trigger"
            printsetvar "MOTION_${idx}_MOTION_LOCATE"       "locate/draw a box around the moving object"

            for VNAME in FILE SPEED
            do
                if variable_set "MOTION_${idx}_MASK_${VNAME}"
                then
                    #------------------------------------------------------------------------------
                    printgroup "default: mask settings"
                    #------------------------------------------------------------------------------
                    break
                fi
            done
                    
            printsetvar "MOTION_${idx}_MASK_FILE"         "PGM file to use as a sensitivity mask"
            printsetvar "MOTION_${idx}_MASK_SPEED"        "dynamically create a mask file"

            for VNAME in CAPTURE_IMAGE CAPTURE_ALL CAPTURE_SNAPSHOT CAPTURE_QUALITY \
                         CAPTURE_MOVIE CAPTURE_LENGTH CAPTURE_TIMELAPS CAPTURE_CODEC \
                         WEBCAM_PORT WEBCAM_MOTION WEBCAM_FRAMERATE
            do
                if variable_set "MOTION_${idx}_${VNAME}"
                then
                    #------------------------------------------------------------------------------
                    printgroup "default: capture settings"
                    #------------------------------------------------------------------------------
                    break
                fi
            done
                    
            printsetvar "MOTION_${idx}_CAPTURE_IMAGE"     "create jpeg file on event"
            printsetvar "MOTION_${idx}_CAPTURE_ALL"       "always save images even if no motion"
            printsetvar "MOTION_${idx}_CAPTURE_SNAPSHOT"  "create snapshot each n seconds"
            printsetvar "MOTION_${idx}_CAPTURE_QUALITY"   "jpeg image quality"
            printsetvar "MOTION_${idx}_CAPTURE_MOVIE"     "create mpeg movie at start of an event"
            printsetvar "MOTION_${idx}_CAPTURE_LENGTH"    "maximum length of an mpeg movie (sec)"
            printsetvar "MOTION_${idx}_CAPTURE_TIMELAPS"  "create timelaps movie saving a frame each n seconds"
            printsetvar "MOTION_${idx}_CAPTURE_CODEC"     "video codec"
          # printsetvar "MOTION_${idx}_TARGET_PATH"       "target directory for pictures/films"
            printsetvar "MOTION_${idx}_WEBCAM_PORT"       "tcp-port of webcam interface"
            printsetvar "MOTION_${idx}_WEBCAM_MOTION"     "output 1 fps when no motion is detected"
            printsetvar "MOTION_${idx}_WEBCAM_FRAMERATE"  "maximum framerate for webcam streams"

            for VNAME in CAMERALOST EVENTSTART EVENTEND MOTIONDETECT MOVIESTART MOVIEEND PICTURESAVE
            do
                if variable_set "MOTION_${idx}_ON_${VNAME}"
                then
                    #------------------------------------------------------------------------------
                    printgroup "default: event settings"
                    #------------------------------------------------------------------------------
                    break
                fi
            done
                    
            printsetvar "MOTION_${idx}_ON_CAMERALOST"     "execute command when camera connection can't be opened or if it is lost"
            printsetvar "MOTION_${idx}_ON_EVENTSTART"     "execute command when an event starts"
            printsetvar "MOTION_${idx}_ON_EVENTEND"       "execute command when an event ends"
            printsetvar "MOTION_${idx}_ON_MOTIONDETECT"   "execute command when motion is detected"
            printsetvar "MOTION_${idx}_ON_MOVIESTART"     "execute command when a movie file is created"
            printsetvar "MOTION_${idx}_ON_MOVIEEND"       "execute command when a movie file is closed"
            printsetvar "MOTION_${idx}_ON_PICTURESAVE"    "execute command when a picture is saved"

            idx=`expr ${idx} + 1`
        done

        #------------------------------------------------------------------------------
        printgroup "end"
        #------------------------------------------------------------------------------
    } > ${generate_conf}

    anykey
}

#==============================================================================
# main
#==============================================================================

#testroot=/soft/jedmotion
 testroot=''

apache2file=${testroot}/etc/config.d/apache2
usbcamfile=${testroot}/etc/config.d/usbcam
motionfile=${testroot}/etc/config.d/motion
installfile=/var/run/motion.install

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        def_doc_root=/var/www/htdocs
        ;;
    *)
        # default eisfair-2
        def_doc_root=/data/www/htdocs
        ;;
esac

# setting defaults
source_conf=${installfile}
generate_conf=${motionfile}

goflag=0

case "$1"
in
    update)
        goflag=1
        ;;
    test)
      # source_conf=${motionfile}.new
        source_conf=${motionfile}

        generate_conf=${testroot}/etc/config.d/mk_motion.test
        goflag=1
        ;;
    *)
        mecho
        mecho "Use one of the following options:"
        mecho
        mecho "  motion-update [update] - the file ${motionfile}.import will be read, the configuration will"
        mecho "                           be checked and an updated mail configuration file will be written."
        mecho
        goflag=0
esac

if [ ${goflag} -eq 1 ]
then
    if [ -f ${source_conf} ]
    then
        # previous configuration file exists
        mecho -info "previous configuration found ..."
        . ${source_conf}

        if [ ${MOTION_N} -eq 0 ]
        then
            if [ -f /etc/config.d/usbcam ]
            then
                # read usbcam parameters
                . ${usbcamfile}

                read_usbcam
            fi
        fi

        rename_variables
        modify_variables
        add_variables
        delete_variables

        create_config
    else    
        mecho -error "no configuration ${source_conf} found - exiting."
        anykey
    fi    
fi    

#==============================================================================
# end
#==============================================================================
